@@ -5,28 +5,24 @@ use warnings;
 use Carp qw/croak/;
 use XSLoader;
 
-our $VERSION= '4.017_001'; # Don't forget to update the TestCompat set for testing against installed decoders!
-our $XS_VERSION= $VERSION; $VERSION= eval $VERSION;
+our $VERSION = '4.002'; # Don't forget to update the TestCompat set for testing against installed decoders!
+our $XS_VERSION = $VERSION; $VERSION= eval $VERSION;
 
 # not for public consumption, just for testing.
-( my $num_version= $VERSION ) =~ s/_//;
-my $TestCompat= [ map sprintf( "%.2f", $_ / 100 ), reverse( 400 .. int( $num_version * 100 ) ) ]; # compat with 4.00 to ...
-sub _test_compat { return ( @$TestCompat, $VERSION ) }
+(my $num_version = $VERSION) =~ s/_//;
+my $TestCompat = [ map sprintf("%.2f", $_/100), reverse( 400 .. int($num_version * 100) ) ]; # compat with 4.00 to ...
+sub _test_compat {return(@$TestCompat, $VERSION)}
 
 # Make sure to keep these constants in sync with the C code in srl_encoder.c.
 # I know they could be exported from C using things like ExtUtils::Constant,
 # but that's too much of a hassle for just three numbers.
-#start-no-tidy
-my ($compress_consts, $full_consts);
-BEGIN {
-$compress_consts= {
+use constant {
     SRL_UNCOMPRESSED => 0,
     SRL_SNAPPY       => 1,
     SRL_ZLIB         => 2,
     SRL_ZSTD         => 3,
 };
-$full_consts=
-#begin generated
+use constant #begin generated
 {
   'SRL_F_ALIASED_DEDUPE_STRINGS' => 4096,
   'SRL_F_CANONICAL_REFS' => 32768,
@@ -37,7 +33,7 @@ $full_consts=
   'SRL_F_CROAK_ON_BLESS' => 4,
   'SRL_F_DEDUPE_STRINGS' => 2048,
   'SRL_F_ENABLE_FREEZE_SUPPORT' => 16384,
-  'SRL_F_ENCODER_COMPRESS_FLAGS_MASK' => 262592,
+  'SRL_F_ENCODER_COMPRESS_FLAGS_MASK' => '0',
   'SRL_F_NOWARN_UNKNOWN_OVERLOAD' => 512,
   'SRL_F_NO_BLESS_OBJECTS' => 8192,
   'SRL_F_REUSE_ENCODER' => 2,
@@ -73,42 +69,30 @@ $full_consts=
                     'SORT_KEYS_PERL_REV',
                     'COMPRESS_ZSTD'
                   ]
-};
-#end generated
-}
-use constant $compress_consts;
-use constant $full_consts;
-#end-no-tidy
+}; #end generated
 
 use Exporter 'import';
-our @EXPORT_OK= (qw(
-    encode_sereal
-    encode_sereal_with_header_data
-    sereal_encode_with_object
-), sort { $a cmp $b } 
-(
-    keys(%$compress_consts),
-    keys(%$full_consts)
-));
-our %EXPORT_TAGS= (
-    all            => \@EXPORT_OK,
-    compress_const => [ sort keys %$compress_consts ],
-    full_const     => [ sort(keys(%$compress_consts),keys(%$full_consts)) ],
+our @EXPORT_OK = qw(
+  encode_sereal
+  encode_sereal_with_header_data
+  sereal_encode_with_object
+  SRL_UNCOMPRESSED
+  SRL_SNAPPY
+  SRL_ZLIB
 );
-
+our %EXPORT_TAGS = (all => \@EXPORT_OK);
 # export by default if run from command line
-our @EXPORT= ( ( caller() )[1] eq '-e' ? @EXPORT_OK : () );
+our @EXPORT = ((caller())[1] eq '-e' ? @EXPORT_OK : ());
 
-sub CLONE_SKIP { 1 }
+sub CLONE_SKIP {1}
 
-XSLoader::load( 'Sereal::Encoder', $XS_VERSION );
+XSLoader::load('Sereal::Encoder', $XS_VERSION);
 
 sub encode_to_file {
-    my ( $self, $file, $struct, $append )= @_;
-    $self= $self->new() unless ref $self;
+    my ($self, $file, $struct, $append)= @_;
     my $mode= $append ? ">>" : ">";
     open my $fh, $mode, $file
-        or die "Failed to open '$file' for " . ( $append ? "append" : "write" ) . ": $!";
+        or die "Failed to open '$file' for " . ($append ? "append" : "write") . ": $!";
     print $fh $self->encode($struct)
         or die "Failed to print to '$file': $!";
     close $fh
@@ -116,13 +100,15 @@ sub encode_to_file {
 }
 
 my $flags= sub {
-    my ( $int, $ary )= @_;
-    return map { ( $ary->[$_] and $int & ( 1 << $_ ) ) ? $ary->[$_] : () } ( 0 .. $#$ary );
+    my ($int, $ary)= @_;
+    return map {
+        ($ary->[$_] and $int & (1 << $_)) ? $ary->[$_] : ()
+    } (0..$#$ary);
 };
 
 sub flag_names {
-    my ( $self, $val )= @_;
-    return $flags->( defined $val ? $val : $self->flags, _FLAG_NAME );
+    my ($self, $val)= @_;
+    return $flags->(defined $val ? $val : $self->flags, _FLAG_NAME);
 }
 
 1;
@@ -467,16 +453,6 @@ A header is intended for embedding small amounts of meta data, such as routing
 information, in a document that allows users to avoid deserializing main body
 needlessly.
 
-=head2 encode_to_file
-
-    Sereal::Encoder->encode_to_file($file,$data,$append);
-    $encoder->encode_to_file($file,$data,$append);
-
-Encode the data specified and write it the named file.
-If $append is true then the written data is appended to any
-existing data, otherwise any existing data will be overwritten.
-Dies if any errors occur during writing the encoded data.
-
 =head1 EXPORTABLE FUNCTIONS
 
 =head2 sereal_encode_with_object
@@ -537,7 +513,7 @@ in both time and space efficiency with the best alternatives.
 This mechanism is enabled using the C<freeze_callbacks> option of the encoder.
 It is inspired by the equivalent mechanism in L<CBOR::XS> and differs only
 in one minor detail, explained below. The general mechanism is documented
-in the I<A GENERIC OBJECT SERIALIATION PROTOCOL> section of L<Types::Serialiser>.
+in the I<A GENERIC OBJECT SERIALIATION PROTOCOL> section of L<Types::Serializer>.
 Similar to CBOR using C<CBOR>, Sereal uses the string C<Sereal> as a serializer
 identifier for the callbacks.
 
